@@ -4,14 +4,13 @@ from ocp_resources.resource import NamespacedResource
 
 
 class ChaosEngine(NamespacedResource):
+
     api_group = NamespacedResource.ApiGroup.LITMUS_IO
-    api_version = NamespacedResource.ApiVersion.V1ALPHA1
 
     class EngineStatus:
-        # TODO: Rename to Uppercase
-        Initialized = "initialized"
-        Completed = "completed"
-        Stopped = "stopped"
+        INITIALIZED = "initialized"
+        COMPLETED = "completed"
+        STOPPED = "stopped"
 
     @property
     def engine_status(self):
