@@ -34,6 +34,7 @@ class NodeNetworkState(Resource):
         self.desired_state = status.get("desiredState", {"interfaces": []})
 
     def set_interface(self, interface):
+
         # First drop the interface is's already in the list
         interfaces = [
             iface
@@ -46,28 +47,24 @@ class NodeNetworkState(Resource):
         self.desired_state["interfaces"] = interfaces
 
     def to_dict(self):
-        res = super().to_dict()
-        if self.yaml_file:
-            return res
-
-        res.update(
-            {
-                "spec": {
-                    "nodeName": self.name,
-                    "managed": True,
-                    "desiredState": self.desired_state,
+        super().to_dict()
+        if not self.yaml_file:
+            self.res.update(
+                {
+                    "spec": {
+                        "nodeName": self.name,
+                        "managed": True,
+                        "desiredState": self.desired_state,
+                    }
                 }
-            }
-        )
-        return res
+            )
 
     def apply(self):
-        resource = self.to_dict()
         retries_on_conflict = 3
         while True:
             try:
-                resource["metadata"] = self.instance.to_dict()["metadata"]
-                self.update(resource)
+                self.res["metadata"] = self.instance.to_dict()["metadata"]
+                self.update(self.res)
                 break
             except ConflictError as e:
                 retries_on_conflict -= 1
